<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Έκδοση %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>Το %1 είναι ελεύθερο λογισμικό αλλά η ανάπτυξη του απαιτεί πολύτιμο χρόνο. </translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Παρακαλώ &lt;a href=&apos;%1&apos;&gt;κάντε δωρεά&lt;/a&gt; για να υποστηρίξετε την συνεχή εξέλιξη του %2</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Διανέμεται υπό την &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Περί</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Ότι θα θέλατε να ξέρετε για το %1 και δεν τολμούσατε να ρωτήσετε</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Μπορεί, επίσης, να θέλετε να δοκιμάσετε και τις άλλες μου εφαρμογές:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, μια εφαρμογή του Youtube</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, ένας αναπαραγωγέας μουσικής του YouTube</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Μετάφραση %1 στην μητρική σας γλώσσα με την χρήση %2</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Αδειοδοτημένο στον/ην: %1</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Εισάγετε τις λεπτομέρειες της άδειας χρήσης</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Κωδικός:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Παρακαλώ αποκτήστε την άδεια χρήσης του %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Αυτή η δοκιμαστική έκδοση έληξε.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Χωρίς την άδεια χρήσης, η εφαρμογή θα λήξη σε %1 μέρες</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Αγοράζοντας την πλήρη έκδοση, υποστηρίζετε επίσης την σκληρή δουλειά που έχω κάνει για τη δημιουργία του %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Χρήση της δοκιμαστικής έκδοσης</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Εισαγωγή άδειας χρήσης</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Αγορά άδειας χρήσης</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>Η πλήρη έκδοση σας επιτρέπη να προσθέσετε περισσότερα απο %1 κομμάτια στην λίστα αναπαραγωγής και να ακούτε την μουσική σας χωρίς διακοπές.</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Αγοράστε από %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Διαβάστε περισσότερα</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Artist</source>
        <translation>Καλλιτέχνης</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Τίτλος</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Έτος</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Δημοτικότητα</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Αντίστροφη Σειρά</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ταξινόμηση κατά ...</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Διαβάστε περισσότερα</translation>
    </message>
</context>
<context>
    <name>ArtistListView</name>
    <message>
        <source>Track Count</source>
        <translation>Αριθμός Κομματιών</translation>
    </message>
    <message>
        <source>Album Count</source>
        <translation>Αριθμός Άλμπουμ</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>όνομα</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Έτος</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Δημοτικότητα</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Αντίστροφη Σειρά</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ταξινόμηση κατά ...</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Πίσω</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Πηγαίνετε πίσω</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Καλωσορίσατε στο &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 χρειάζεται να σαρώσει τη μουσική συλλογή σας.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Κάντε χρήση της συλλογή iTunes</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Κάντε χρήση του %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Επιλέξτε ένα φάκελο...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 θα συνδεθεί με την διαδικτυακή υπηρεσία Last.fm και θα περάσει ονόματα καλλιτεχνών και τίτλους άλμπουμ, για να κατεβάσει εξώφυλλα, βιογραφίες και πολλά άλλα.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Εάν έχετε ανησυχίες προσωπικού απορρήτου σχετικά με αυτό μπορείτε να κλείσετε τώρα.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Που είναι η μουσική σας συλλογή;</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Επιλέξτε μια τοποθεσία της μουσικής σας συλλογής.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Εντοπίστε την συλλογή σας</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Εκκαθάριση</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Μια διαδικασία ανίχνευσης βρίσκεται είδη σε εξέλιξη</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>Το %1 ανιχνεύη την μουσική σας συλλογή</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 χρησιμοποιεί &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; για να δημιουργήσει κατάλογό της μουσική σας.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Αυτό θα πάρει χρόνο ανάλογα με το μέγεθος της συλλογή σας και την ταχύτητα του δικτύου.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Πηγαίνετε πάρτε έναν καφέ</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <source>Downloading update...</source>
        <translation>Μεταφόρτωση ενημερώσεων...</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Σύρετε εδώ για να προσθέσετε στη λίστα αναπαραγωγής</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Καλλιτέχνες</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Δίσκοι</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Φάκελοι</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Αναπαραγωγή</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Παύση</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Αναπαραγωγή/Παύση</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Σταμάτημα</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Διακοπή της αναπαραγωγής μετά το τρέχον κομμάτι</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Επόμενο κομμάτι</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Προηγούμενο κομμάτι </translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Αύξηση έντασης ήχου</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Μείωση έντασης ήχου</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Σίγαση</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Αναζήτηση μπροστά</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Αναζήτηση πίσω</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>Αποτυχία πιστοποίησης</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>Είσοδος στο %1</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Όνομα Χρήστη:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Κωδικός:</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation>Κάντε εγγραφή στο %1 για ένα λογαριασμό</translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>Ξεχάσατε το &lt;a href=&apos;%1&apos;&gt;Όνομα Χρήστη&lt;/a&gt; ή &lt;a href=&apos;%2&apos;&gt;Κωδικός Χρήστη&lt;/a&gt;;</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Πίσω</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Πηγαίνετε στην προηγούμενη προβολή</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Πληροφορίες</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Εφμάνιση πληροφοριών για το τρέχον κομμάτι</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>Π&amp;ροηγούμενο</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Επιστροφή στο προηγούμενο κομμάτι</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>Ε&amp;πόμενο</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Μετάβαση στο επόμενο κομμάτι</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Α&amp;ναπαραγωγή</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Έναρξη αναπαραγωγής</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Πλήρης &amp;οθόνη</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Πήγαινε σε πλήρη οθόνη</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Α&amp;φαίρεση</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Αφαίρεση των συγκεκριμένων κομματιών από την λίστα αναπαραγωγής</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Μετακίνηση &amp;επάνω</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Μετακίνηση επάνω των επιλεγμένων κομματιών</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Μετακίνση &amp;κάτω</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Μετακίνηση κάτω των επιλεγμένων κομματιών</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Έ&amp;ξοδος</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Αντίο</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>Αλλ&amp;αγή φακέλου συλλογής...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Επιλογή διαφορετικού φακέλου μουσικής συλλογής</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Ισ&amp;τοσελίδα</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 στο διαδίκτυο</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Κάντε μία &amp;δωρεά</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Παρακαλώ υποστηρίξτε την διαρκεί βελτιώση του %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Π&amp;ερί</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Πληροφορίες για το %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>Ε&amp;κκαθάριση</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Αφαίρεση όλων των κομματιών από την λίστα αναπαραγωγής</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>Αν&amp;ακάτεμα</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Κατάσταση τυχαίας αναπαραγωγής</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>Ε&amp;πανάληψη</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Αναπαραγωγή του πρώτου τραγουδιού μετά την αναπαραγωγή όλων των κομματιών</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Σίγαση ήχου</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>Ε&amp;φαρμογή</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>Α&amp;ναπαραγωγή</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>Λίστα αναπαρα&amp;γωγής</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>Π&amp;ροβολή</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Βοή&amp;θεια</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Πιέστε το %1 για να αυξήσετε την ένταση και το %2 για να την χαμηλώσετε</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Ανοιγμα του %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Ενημέρωση συλλογής...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Ενημέρωση της συλλογήε - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Η συλλογή ενημερώθηκε</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Μοιραίο σφάλμα:%1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Σφάλμα:%1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Έξοδος από &amp;πλήρη οθόνη</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Απομένων χρόνος: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Ένσταση ήχου στο %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Έχει πραγματοποιηθεί σίγαση ήχου</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Ο ήχος επανήλθε</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Αποκτήστε την πλήρη έκδοση</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 έκδοση %2 είναι τώρα διαθέσιμη.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Υπενθήμηση αργότερα</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Ενημέρωση</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Παράθυρο</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Ελαχιστοποίηση</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Αγοράστε το %1...</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>%Σταμάτημα Μετά Από Αυτό Το Κομμάτι</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>&amp;Scrobbling</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>Αποστολή τίτλων κομματιών, που έχουν αναπαραχθεί, στο %1</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>&amp;Αποσύνδεση από %1</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Αναφέρετε κάποιο σφάλμα...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Αναζήτηση</translation>
    </message>
    <message>
        <source>%1 finished scanning your music collection</source>
        <translation>%1 ολοκλήρωσε τη σάρωση της μουσικής σας συλλογής</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Σύρτε αντικείμενα εδώ</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Η λίστα αναπαραγωγής τελείωσε</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Αυτή είναι μια δοκιμαστίκη έκδοση του %1</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Επιτρέπει να αναπαράγεται ορισμένα κομμάτια για να δοκιμάσετε άν αυτή η εφαρμογή δουλεύει για σας.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Συνέχεια</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Αποκτήστε την πλήρη έκδοση</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Μια νέα έκδοση του %1 είναι διαθέσιμη!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>Η %1 %2 είναι διαθέσιμη. Έχετε την %3</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Θα θέλατε να την κατεβάσετε τώρα;</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Παράλειψη αυτής της έκδοσης</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Υπενθύμισε το μου αργότερα</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Εγκατάσταση Ενημερώσεων</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Επικόλληση</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Στην δοκιμαστική έκδοση μπορείτε να προσθέσετε μόνο %1 κομμάτια στην λίστα αναπαραγωγής.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>Η λίστα αναπαραγωγής είναι άδεια</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 κομμάτια - Το συνολικό μήκος είναι %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Αναζήτηση</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>Η αναζήτηση σας δεν είχε κανένα αποτέλεσμα.</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Κομμάτια</translation>
    </message>
</context>
</TS>